@@ -139,7 +139,7 @@ streamOfProp :: C.Property -> C.Stream
 streamOfProp prop =
   C.Stream { C.streamId = 42
            , C.streamBuffer = []
-           , C.streamExpr = C.propertyExpr prop
+           , C.streamExpr = C.extractProp (C.propertyProp prop)
            , C.streamExprType = C.Bool }
 
 stream :: C.Stream -> Trans Node
